# SOcial COMmunication Library

**Socom** is a python package for the analysis of social communication using network-based approaches created and maintained by the Uppsala University Information Laboratory ([InfoLab](https://uuinfolab.github.io).


While the ideas behind _socom_ have been developed during years, the active development of the library has not started until recently (March 2024). Therefore, be aware that this is a pre-alpha version of the library with limited functionality.


## Contact

For any inquiries regarding the library you can contact <davide.vega@it.uu.se>